@@ -61,20 +61,33 @@ gchar * gataxx_gconf_get_string (gchar *key);
 gint gataxx_gconf_get_int (gchar *key, gint default_int);
 gboolean gataxx_gconf_get_bool (gchar *key, gint default_bool);
 
+static gint clamp_int (gint input, gint low, gint high)
+{
+	if (input < low)
+		input = low;
+	if (input > high)
+		input = high;
+
+	return input;
+}
+
 void 
 load_properties (void)
 {
 	black_computer_level =
 		gataxx_gconf_get_int ("/apps/gataxx/blacklevel", 0);
+	black_computer_level = clamp_int (black_computer_level, 0, 3);
 
 	white_computer_level =
 		gataxx_gconf_get_int ("/apps/gataxx/whitelevel", 0);
-
+	white_computer_level = clamp_int (white_computer_level, 0, 3);
+	
 	tile_set = gataxx_gconf_get_string ("/apps/gataxx/tileset");
 	if (tile_set == NULL)
 		tile_set = g_strdup("classic.png");
 
 	animate = gataxx_gconf_get_int ("/apps/gataxx/animate", 2);
+	animate = clamp_int (animate, 0, 2);
 
 	if ((quick_moves =
 	     gataxx_gconf_get_bool ("/apps/gataxx/quickmoves", FALSE)))
@@ -85,7 +98,9 @@ load_properties (void)
 		computer_speed = COMPUTER_MOVE_DELAY;
 	}
 	flip_final = gataxx_gconf_get_bool ("/apps/gataxx/flipfinal", TRUE);
-	
+
+	if (flip_pixmaps_id)
+		g_source_remove (flip_pixmaps_id);
 	switch (animate) {
 		case 0:
 			flip_pixmaps_id = g_timeout_add (100, flip_pixmaps, NULL);
@@ -262,9 +277,10 @@ void
 fill_menu (GtkWidget *menu)
 {
         struct dirent *e;
+	/* Note that we are sharing pixmaps with iagno here. */
 	gchar *dname = gnome_program_locate_file (NULL,
 						  GNOME_FILE_DOMAIN_APP_PIXMAP,
-						  ("gataxx"), FALSE, NULL);
+						  ("iagno"), FALSE, NULL);
         DIR *dir;
         int itemno = 0;
 
@@ -337,7 +353,7 @@ show_properties_dialog (void)
 	
 	/* Players tab */
 	
-	label = gtk_label_new (_("Players"));
+	label = gtk_label_new_with_mnemonic (_("_Players"));
 
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
@@ -450,7 +466,7 @@ show_properties_dialog (void)
 
 	/* Appearance tab */
 	
-	label = gtk_label_new (_("Appearance"));
+	label = gtk_label_new_with_mnemonic (_("_Appearance"));
 
 	table = gtk_table_new (1, 2, FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (table), 6);
@@ -526,33 +542,16 @@ show_properties_dialog (void)
 
 }	
 
-/* First checks gconf, then schema, then defaults to the value passed. */
 gint
 gataxx_gconf_get_int (gchar *key, gint default_int)
 {
-	GConfValue *value = NULL;
-	GConfValue *schema_value = NULL;
+	GError *error = NULL;
 	gint retval;
 
-	value = gconf_client_get (gataxx_gconf_client, key, NULL);
-	if (value == NULL)
+	retval = gconf_client_get_int (gataxx_gconf_client, key, &error);
+	if (error != NULL) {
+		g_error_free (error);
 		return default_int;
-
-	if (value->type == GCONF_VALUE_INT) {
-		retval = gconf_value_get_int (value);
-		gconf_value_free (value);
-	}
-	else {
-		schema_value = gconf_client_get_default_from_schema
-			(gataxx_gconf_client, key, NULL);
-		if (schema_value == NULL) {
-			retval = default_int;
-		}
-		else {
-			retval = gconf_value_get_int (schema_value);
-		}
-		gconf_value_free (value);
-		gconf_value_free (schema_value);
 	}
 
 	return retval;
@@ -561,62 +560,30 @@ gataxx_gconf_get_int (gchar *key, gint default_int)
 gboolean
 gataxx_gconf_get_bool (gchar *key, gboolean default_bool)
 {
-	GConfValue *value = NULL;
-	GConfValue *schema_value = NULL;
+	GError *error = NULL;
 	gboolean retval;
 
-	value = gconf_client_get (gataxx_gconf_client, key, NULL);
-	if (value == NULL)
+	retval = gconf_client_get_bool (gataxx_gconf_client, key, &error);
+	if (error != NULL) {
+		g_error_free (error);
 		return default_bool;
-
-	if (value->type == GCONF_VALUE_BOOL) {
-		retval = gconf_value_get_bool (value);
-		gconf_value_free (value);
-	}
-	else {
-		schema_value = gconf_client_get_default_from_schema
-			(gataxx_gconf_client, key, NULL);
-		if (schema_value == NULL) {
-			retval = default_bool;
-		}
-		else {
-			retval = gconf_value_get_bool (schema_value);
-		}
-		gconf_value_free (value);
-		gconf_value_free (schema_value);
 	}
 
 	return retval;
 }
 
-/* Returns gchar* you should free with g_free(). */
-/* First checks gconf, then schema. Returns NULL if not found in either. */
+/* Returns gchar* you should free with g_free(). Returns NULL on not-found
+ * or other error. */
 gchar *
 gataxx_gconf_get_string (gchar *key)
 {
-	GConfValue *value = NULL;
-	GConfValue *schema_value = NULL;
-	gchar *retval = NULL;
+	GError *error = NULL;
+	gchar *retval;
 
-	value = gconf_client_get (gataxx_gconf_client, key, NULL);
-	if (value == NULL)
+	retval = gconf_client_get_string (gataxx_gconf_client, key, &error);
+	if (error != NULL) {
+		g_error_free (error);
 		return NULL;
-
-	if (value->type == GCONF_VALUE_STRING) {
-		retval = g_strdup (gconf_value_get_string (value));
-		gconf_value_free (value);
-	}
-	else {
-		schema_value = gconf_client_get_default_from_schema
-			(gataxx_gconf_client, key, NULL);
-		if (schema_value == NULL) {
-			retval = NULL;
-		}
-		else {
-			retval = g_strdup (gconf_value_get_string (schema_value));
-		}
-		gconf_value_free (value);
-		gconf_value_free (schema_value);
 	}
 
 	return retval;
