@@ -44,11 +44,11 @@ struct _MoveHistory
 	gint8 me;
 };
 
-void new_game_cb(GtkWidget *widget, gpointer data);
-void new_net_game_cb(GtkWidget *widget, gpointer data);
-void quit_game_cb(GtkWidget *widget, gpointer data);
-void undo_move_cb(GtkWidget *widget, gpointer data);
-void redo_move_cb(GtkWidget *widget, gpointer data);
+void new_game_cb (GtkWidget *widget, gpointer data);
+void new_net_game_cb (GtkWidget *widget, gpointer data);
+void quit_game_cb (GtkWidget *widget, gpointer data);
+void undo_move_cb (GtkWidget *widget, gpointer data);
+void redo_move_cb (GtkWidget *widget, gpointer data);
 void black_level_cb (GtkWidget *widget, gpointer data);
 void white_level_cb (GtkWidget *widget, gpointer data);
 void about_cb (GtkWidget *widget, gpointer data);
@@ -57,28 +57,29 @@ void comp_white_cb (GtkWidget *widget, gpointer data);
 void quick_moves_cb (GtkWidget *widget, gpointer data);
 void anim_cb (GtkWidget *widget, gpointer data);
 void anim_stagger_cb (GtkWidget *widget, gpointer data);
-void load_tiles_cb(GtkWidget *widget, gpointer data);
-void fill_menu(GtkWidget *menu);
-void set_selection(GtkWidget *widget, void *data);
-void free_str(GtkWidget *widget, void *data);
-void load_tiles_callback(GtkWidget *widget, void *data);
-void cancel(GtkWidget *widget, void *data);
+void load_tiles_cb (GtkWidget *widget, gpointer data);
+void fill_menu (GtkWidget *menu);
+void set_selection (GtkWidget *widget, void *data);
+void free_str (GtkWidget *widget, void *data);
+void load_tiles_callback (GtkWidget *widget, void *data);
+void cancel (GtkWidget *widget, void *data);
 gint expose_event (GtkWidget *widget ,GdkEventExpose *event);
 gint configure_event (GtkWidget *widget, GdkEventConfigure *event);
 gint button_press_event (GtkWidget *widget, GdkEventButton *event);
 void gui_draw_pixmap(gint which, gint x, gint y);
-void gui_draw_pixmap_buffer(gint which, gint x, gint y);
-gint flip_pixmaps(gpointer data);
-void init_new_game();
-void create_window();
-void gui_status();
-void gui_message(gchar *message);
-guint check_computer_players();
-void load_pixmaps();
+void gui_draw_pixmap_buffer (gint which, gint x, gint y);
+gint flip_pixmaps (gpointer data);
+void init_new_game (void);
+void clear_board (void);
+void create_window (void);
+void gui_status (void);
+void gui_message (gchar *message);
+guint check_computer_players (void);
+void load_pixmaps (void);
 void properties_cb (GtkWidget *widget, gpointer data);
-void set_bg_color(void);
-void gui_draw_grid(void);
+void set_bg_color (void);
+void gui_draw_grid (void);
 
-extern guint whose_turn;
+extern guint whose_turn, game_in_progress;
 
 #endif
