@@ -1,14 +1,12 @@
 /*
  * Gnome-Mahjonggg-solubility header file
- * (C) 1998 the Free Software Foundation
+ * (C) 1998-2002 the Free Software Foundation
  *
  *
  * Author: Michael Meeks.
  *
- *
- * http://www.imaginator.com/~michael
- * michael@imaginator.com
- *
+ * http://www.gnome.org/~michael
+ * michael@ximian.com
  */
 
 /* If defined this allows graphical placement debugging.
@@ -16,7 +14,7 @@
  * in keyPress to change things */
 /* #define PLACE_DEBUG */
 
-extern void generate_game () ;
-extern void generate_dependancies () ;
-extern int tile_free (int) ;
+extern int  tile_free             (int);
+extern void generate_game         (guint seed);
+extern void generate_dependancies (void);
 
